==> tasks-v1.8.8.zip: tasks/messages/nl/base.php <==
<?php
return [
  '1 Day before' => '1 dag ervoor',
  '1 Month before' => '1 maand ervoor',
  '1 Week before' => '1 week ervoor',
  '2 Days before' => '2 dagen ervoor',
  '2 Weeks before' => '2 weken ervoor',
  '3 Weeks before' => '3 weken ervoor',
  '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Alleen toegewezen gebruikers</strong> mogen deze taak werken.',
  '<strong>Confirm</strong> task deletion' => '<strong>Bevestigen</ strong>het verwijderen van de taak',
  '<strong>Create</strong> task list' => '<strong>Takenlijst</strong> maken',
  '<strong>Edit</strong> task' => '<strong>Bewerk</ strong> taak',
  '<strong>Edit</strong> task list' => '<strong>Takenlijst</strong> bewerken',
  '<strong>New</strong> Task' => '<strong>Nieuwe</strong> taak',
  '<strong>Task</strong> Overview' => '<strong>Taak</strong> Overzicht',
  '<strong>Tasks</strong>' => '<strong>Taken</strong>',
  '<strong>Tasks</strong> module configuration' => '<strong>Taken</strong> moduleconfiguratie',
  '<strong>Your</strong> tasks' => '<strong>Mijn</strong> taken',
  'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => 'Een widget is een element dat is toegevoegd aan de zijbalk van een stream. In dit geval biedt het gebruikers een kort overzicht van hun taken.',
  'Accept Task' => 'Taak accepteren',
  'Add Deadline to space calendar' => 'Voeg de uiterste datum toe aan de ruimtekalender',
  'Add checkpoint...' => 'Controlepunt toevoegen',
  'Add checkpoints to the task to highlight the individual steps required to complete it.' => 'Voeg controlepunten toe aan de taak om de afzonderlijke stappen te markeren die nodig zijn om de taak te voltooien.',
  'Add entry to main navigation' => 'Item toevoegen aan hoofdnavigatie',
  'Add reminder' => 'Herinnering toevoegen',
  'Add responsible users' => 'Voeg verantwoordelijke gebruikers toe',
  'Add schedule to the space calendar' => 'Voeg schema toe aan de ruimtekalender',
  'Add task' => 'Taak toevoegen',
  'Add to space calendar' => 'Toevoegen aan de ruimtekalender',
  'Additional options' => 'Extra opties',
  'All Day' => 'De hele dag',
  'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Hiermee kan de gebruiker nieuwe taken maken, de gebruiker kan alleen eigen taken bewerken en verwijderen.',
  'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Hiermee kan de gebruiker taken en lijsten maken, verwijderen, bewerken en sorteren.',
  'Allows the user to process unassigned tasks' => 'Hiermee kan de gebruiker niet-toegewezen taken verwerken.',
  'Already requested' => 'Al aangevraagd',
  'Any user with a "Process unassigned tasks" permission can work on this task' => 'Elke gebruiker met de machtiging «Kan niet-toegewezen taken verwerken» kan aan deze taak werken',
  'Anyone can work on this task!' => 'Iedereen kan aan deze taak werken!',
  'Assign myself' => 'Mezelf toewijzen',
  'Assign users' => 'Wijs gebruikers toe',
  'Assigned' => 'Toegewezen',
  'Assigned users' => 'Toegewezen gebruikers',
  'Assignment' => 'Toewijzing',
  'Assignments:' => 'Toewijzingen:',
  'At least 1 Hour before' => 'Ten minste 1 uur ervoor',
  'At least 2 Hours before' => 'Ten minste 2 uur ervoor',
  'Attachments' => 'Bijlagen',
  'Begin Task' => 'Begin aan taak',
  'Checklist Items' => 'Checklist items',
  'Checklist:' => 'Controlelijst:',
  'Checkpoints' => 'Controlepunten',
  'Choose if you want the module to appear in the main navigation.' => 'Kies of u de module in de hoofdnavigatie wilt laten verschijnen.',
  'Close' => 'Sluiten',
  'Color' => 'Kleur',
  'Completed' => 'Voltooid',
  'Completed lists' => 'Voltooide taaklijst',
  'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => 'Configureer de Taken-module om aan uw specifieke vereisten en behoeften te voldoen. U kunt individuele instellingen definiëren en bijvoorbeeld beslissen of een widget wordt weergegeven.',
  'Continue Review' => 'Doorgaan met beoordeling',
  'Create tasks' => 'Taken maken',
  'Created by me' => 'Gemaakt door mij',
  'Date' => 'Datum',
  'Deadline at' => 'Uiterste datum om',
  'Deadline: ' => 'Uiterste datum',
  'Delete' => 'Verwijder',
  'Delete list' => 'Taaklijst verwijderen',
  'Description' => 'Beschrijving',
  'Do not remind' => 'Niet herinneren',
  'Do you really want to delete this task?' => 'Wilt u deze taak echt verwijderen?',
  'Don\'t add to calendar' => 'Voeg niet toe aan de kalender',
  'Drag entry' => 'Sleep het item',
  'Edit' => 'Bijwerken',
  'Edit item (empty field will be removed)...' => 'Item bewerken (leeg veld wordt verwijderd) ...',
  'Edit list' => 'Lijst bijwerken',
  'End' => 'Einde',
  'End Date' => 'Einddatum',
  'End Time' => 'Eindtijd',
  'End date' => 'Einddatum',
  'End time must be after start time!' => 'Eindtijd moet na de starttijd liggen!',
  'Extend deadline request' => 'Verleng uiterste datum',
  'Filter' => 'Filter',
  'Filter by status' => 'Filteren op status',
  'Filter by title' => 'Filteren op omschrijving',
  'Filter tasks' => 'Filter taken',
  'Finish Task' => 'Voltooi de taak',
  'General' => 'Algemeen',
  'General Settings' => 'Algemene instellingen',
  'Hide this list once all tasks are completed' => 'Verberg deze lijst zodra alle taken zijn voltooid.',
  'I\'m assigned' => 'Toegewezen aan mij',
  'I\'m responsible' => 'Mijn verantwoordelijkheid',
  'If empty any user can complete the task.' => 'Indien leeg kan elke gebruiker de taak voltooien.',
  'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Als er geen toegewezen gebruiker is geselecteerd, kan elk ruimtelid met de machtiging om niet-toegewezen taken te verwerken, de taak verwerken.',
  'In Progress' => 'Bezig',
  'In Review' => 'In beoordeling',
  'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'Als de beoordelingsoptie actief is, moet een <strong>verantwoordelijke gebruiker</strong> deze taak afwijzen of bevestigen voordat deze is voltooid.',
  'Invalid task list selection.' => 'Ongeldige selectie van een takenlijst.',
  'Let Task Review' => 'Laten we taken gaan beoordelen.',
  'Main Navigation' => 'Hoofdnavigatie',
  'Manage tasks' => 'Beheer taken',
  'Maximum number of entries in widget' => 'Maximaal aantal items in widget',
  'Module Widget' => 'Module Widget',
  'New list or search' => 'Nieuw overzicht of zoekopdracht',
  'No Scheduling set for this Task' => 'Geen planning opgegeven voor deze taak',
  'No pending tasks found' => 'Geen openstaande taken gevonden',
  'No results found for the given filter.' => 'Geen resultaten gevonden voor het opgegeven filter.',
  'Open Task' => 'Open taak',
  'Other Tasks' => 'Andere taken',
  'Overdue' => 'Te laat',
  'Overview' => 'Overzicht',
  'Parent Task' => 'Bovenliggende taak',
  'Pending' => 'In afwachting',
  'Pending Review' => 'In afwachting van een beoordeling',
  'Process unassigned tasks' => 'Verwerk niet-toegewezen taken',
  'Ready For Review' => 'Klaar voor beoordeling',
  'Receive Notifications for Task Reminder.' => 'Ontvang meldingen voor taakherinnering.',
  'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Meldingen ontvangen voor taken (uiterste datum wijzigingen, statuswijzigingen ...).',
  'Reject Task' => 'Taak weigeren',
  'Remind Mode' => 'Herinneringsmodus',
  'Reminder' => 'Herinnering',
  'Reminder sent' => 'Herinnering verstuurd',
  'Reminders' => 'Herinneringen',
  'Request extension' => 'Verzoek om verlenging',
  'Request sent' => 'Verzoek verzonden',
  'Reset Task' => 'Taak opnieuw instellen',
  'Responsible' => 'Verantwoordelijk',
  'Responsible users' => 'Verantwoordelijke gebruikers',
  'Review by responsible user required' => 'Beoordeling door verantwoordelijke gebruiker vereist',
  'Scheduling' => 'Planning',
  'Show widget in Spaces' => 'Widget weergeven in Ruimtes',
  'Show widget on Dashboard' => 'Widget weergeven op dashboard',
  'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Toon {count} voltooide {countTasks,plural,=1{taak} other{taken}} meer.',
  'Sort Order' => 'Sorteervolgorde',
  'Sort order' => 'Sorteervolgorde',
  'Spaces' => 'Ruimten',
  'Start' => 'Start',
  'Start Date' => 'Startdatum',
  'Start Time' => 'Starttijd',
  'Start date' => 'Begindatum',
  'Starting at' => 'Beginnend bij',
  'Status' => 'Status',
  'Task' => 'Taak',
  'Task List' => 'Takenlijst',
  'Task Users have been notified' => 'De betrokken gebruikers zijn op de hoogte gebracht.',
  'Task content ID' => 'Taakinhoud-ID',
  'Task {task} in space {spaceName} ends at {dateTime}.' => 'Taak {task} in ruimte {spaceName} eindigt om {dateTime}.',
  'Task {task} in space {spaceName} starts at {dateTime}.' => 'Taak {task} in ruimte {spaceName} begint om {dateTime}.',
  'Tasks' => 'Taken',
  'Tasks: Reminder' => 'Taken: herinnering',
  'This task can only be processed by assigned and responsible users.' => 'Alleen toegewezen of verantwoordelijke gebruikers kunnen werken aan deze taak.',
  'This task requires to be reviewed by a responsible' => 'Een verantwoordelijk moet deze taak beoordelen.',
  'Time Zone' => 'Tijdzone',
  'Title' => 'Samenvatting',
  'Title and Color' => 'Samenvatting en kleur',
  'Title of your task list' => 'Naam van uw takenlijst',
  'Today' => 'Vandaag',
  'Unsorted' => 'Niet toevoegen aan lijst',
  'View Online' => 'Bekijk online',
  'You are assigned!' => 'U bent toegewezen!',
  'You are responsible!' => 'U bent verantwoordelijk',
  'You have insufficient permissions to perform that operation!' => 'U hebt onvoldoende bevoegdheid om deze bewerking uit te voeren!',
  'Your Reminder for task {task}' => 'Uw herinnering voor taak {task}',
  'ending Review' => 'Beoordeling beëindigen',
  'view all' => 'Bekijk alles',
  '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{# dag} other{# dagen}} resterend',
  '{displayName} is assigned to this task' => '{displayName} is toegewezen aan deze taak',
  '{displayName} is responsible for this task' => '{displayName} is verantwoordelijk voor deze taak',
  '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} heeft u verantwoordelijk gemaakt voor taak {task} vanuit de ruimte {spaceName}.',
  '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} wees taak {task} aan u toe in ruimte {spaceName}.',
  '{userName} completed Task {task} in space {spaceName}.' => '{userName} voltooide taak {task} in ruimte {spaceName}.',
  '{userName} completed task {task}.' => '{userName} voltooide taak {task}.',
  '{userName} finished task {task}.' => '{userName} heeft de taak {task} voltooid.',
  '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} wijzigde de uiterste datum voor taak {task} in ruimte {spaceName}.',
  '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} opende taak {task} opnieuw in ruimte {spaceName}.',
  '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} keurde taak {task} in ruimte {spaceName} af als onvolledig.',
  '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName} markeerde taak {taak} in ruimte {spaceName} als voltooid.',
  '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} vraagt om het verschuiven van de uiterste datum voor taak {task} in ruimte {spaceName}.',
  '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} vraagt u om taak {task} in ruimte {spaceName} te bekijken.',
  '{userName} reset task {task}.' => '{userName} stelde taak {task} opnieuw in..',
  '{userName} reviewed task {task}.' => '{userName} beoordeelde taak {task}.',
  '{userName} started working on Task {task} in space {spaceName}.' => '{userName} begon te werken aan Task {task} in ruimte {spaceName}.',
  '{userName} works on task {task}.' => '{userName} werkt aan taak {task}.',
];

==> tasks-v1.9.2.zip: tasks/messages/nl/base.php <==
<?php
return [
  '1 Day before' => '1 dag ervoor',
  '1 Month before' => '1 maand ervoor',
  '1 Week before' => '1 week ervoor',
  '2 Days before' => '2 dagen ervoor',
  '2 Weeks before' => '2 weken ervoor',
  '3 Weeks before' => '3 weken ervoor',
  '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Alleen toegewezen gebruikers</strong> mogen deze taak werken.',
  '<strong>Confirm</strong> task deletion' => '<strong>Bevestigen</ strong>het verwijderen van de taak',
  '<strong>Create</strong> task list' => '<strong>Takenlijst</strong> maken',
  '<strong>Edit</strong> task' => '<strong>Bewerk</ strong> taak',
  '<strong>Edit</strong> task list' => '<strong>Takenlijst</strong> bewerken',
  '<strong>New</strong> Task' => '<strong>Nieuwe</strong> taak',
  '<strong>Task</strong> Overview' => '<strong>Taak</strong> Overzicht',
  '<strong>Tasks</strong>' => '<strong>Taken</strong>',
  '<strong>Tasks</strong> module configuration' => '<strong>Taken</strong> moduleconfiguratie',
  '<strong>Your</strong> tasks' => '<strong>Mijn</strong> taken',
  'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => 'Een widget is een element dat is toegevoegd aan de zijbalk van een stream. In dit geval biedt het gebruikers een kort overzicht van hun taken.',
  'Accept Task' => 'Taak accepteren',
  'Add Deadline to space calendar' => 'Voeg de uiterste datum toe aan de ruimtekalender',
  'Add checkpoint...' => 'Controlepunt toevoegen',
  'Add checkpoints to the task to highlight the individual steps required to complete it.' => 'Voeg controlepunten toe aan de taak om de afzonderlijke stappen te markeren die nodig zijn om de taak te voltooien.',
  'Add entry to main navigation' => 'Item toevoegen aan hoofdnavigatie',
  'Add reminder' => 'Herinnering toevoegen',
  'Add responsible users' => 'Voeg verantwoordelijke gebruikers toe',
  'Add schedule to the space calendar' => 'Voeg schema toe aan de ruimtekalender',
  'Add task' => 'Taak toevoegen',
  'Add to space calendar' => 'Toevoegen aan de ruimtekalender',
  'Additional options' => 'Extra opties',
  'All Day' => 'De hele dag',
  'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Hiermee kan de gebruiker nieuwe taken maken, de gebruiker kan alleen eigen taken bewerken en verwijderen.',
  'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Hiermee kan de gebruiker taken en lijsten maken, verwijderen, bewerken en sorteren.',
  'Allows the user to process unassigned tasks' => 'Hiermee kan de gebruiker niet-toegewezen taken verwerken.',
  'Already requested' => 'Al aangevraagd',
  'Assign myself' => 'Mezelf toewijzen',
  'Assign users' => 'Wijs gebruikers toe',
  'Assigned users' => 'Toegewezen gebruikers',
  'Assignment' => 'Toewijzing',
  'Assignments' => 'Opdrachten',
  'At least 1 Hour before' => 'Ten minste 1 uur ervoor',
  'At least 2 Hours before' => 'Ten minste 2 uur ervoor',
  'Attachments' => 'Bijlagen',
  'Begin Task' => 'Begin aan taak',
  'Checklist Items' => 'Checklist items',
  'Checklist:' => 'Controlelijst:',
  'Checkpoints' => 'Controlepunten',
  'Choose if you want the module to appear in the main navigation.' => 'Kies of u de module in de hoofdnavigatie wilt laten verschijnen.',
  'Close' => 'Sluiten',
  'Color' => 'Kleur',
  'Completed' => 'Voltooid',
  'Completed lists' => 'Voltooide taaklijst',
  'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => 'Configureer de Taken-module om aan uw specifieke vereisten en behoeften te voldoen. U kunt individuele instellingen definiëren en bijvoorbeeld beslissen of een widget wordt weergegeven.',
  'Continue Review' => 'Doorgaan met beoordeling',
  'Create tasks' => 'Taken maken',
  'Created by me' => 'Gemaakt door mij',
  'Date' => 'Datum',
  'Deadline' => 'Uiterste termijn',
  'Deadline: ' => 'Uiterste datum',
  'Delete' => 'Verwijder',
  'Delete list' => 'Taaklijst verwijderen',
  'Description' => 'Beschrijving',
  'Do not remind' => 'Niet herinneren',
  'Do you really want to delete this task?' => 'Wilt u deze taak echt verwijderen?',
  'Don\'t add to calendar' => 'Voeg niet toe aan de kalender',
  'Edit' => 'Bijwerken',
  'Edit item (empty field will be removed)...' => 'Item bewerken (leeg veld wordt verwijderd) ...',
  'Edit list' => 'Lijst bijwerken',
  'End' => 'Einde',
  'End Date' => 'Einddatum',
  'End Time' => 'Eindtijd',
  'End date' => 'Einddatum',
  'End time must be after start time!' => 'Eindtijd moet na de starttijd liggen!',
  'Extend deadline request' => 'Verleng uiterste datum',
  'Filter' => 'Filter',
  'Filter by status' => 'Filteren op status',
  'Filter by title' => 'Filteren op omschrijving',
  'Filter tasks' => 'Filter taken',
  'Finish Task' => 'Voltooi de taak',
  'General' => 'Algemeen',
  'General Settings' => 'Algemene instellingen',
  'Hide this list once all tasks are completed' => 'Verberg deze lijst zodra alle taken zijn voltooid.',
  'I\'m assigned' => 'Toegewezen aan mij',
  'I\'m responsible' => 'Mijn verantwoordelijkheid',
  'ID' => 'ID',
  'If empty any user can complete the task.' => 'Indien leeg kan elke gebruiker de taak voltooien.',
  'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Als er geen toegewezen gebruiker is geselecteerd, kan elk ruimtelid met de machtiging om niet-toegewezen taken te verwerken, de taak verwerken.',
  'In Progress' => 'Bezig',
  'In Review' => 'In beoordeling',
  'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'Als de beoordelingsoptie actief is, moet een <strong>verantwoordelijke gebruiker</strong> deze taak afwijzen of bevestigen voordat deze is voltooid.',
  'Invalid task list selection.' => 'Ongeldige selectie van een takenlijst.',
  'Let Task Review' => 'Laten we taken gaan beoordelen.',
  'Main Navigation' => 'Hoofdnavigatie',
  'Manage tasks' => 'Beheer taken',
  'Maximum number of entries in widget' => 'Maximaal aantal items in widget',
  'Module Widget' => 'Module Widget',
  'New list or search' => 'Nieuw overzicht of zoekopdracht',
  'No Scheduling set for this Task' => 'Geen planning opgegeven voor deze taak',
  'No pending tasks found' => 'Geen openstaande taken gevonden',
  'No results found for the given filter.' => 'Geen resultaten gevonden voor het opgegeven filter.',
  'Open Task' => 'Open taak',
  'Other Tasks' => 'Andere taken',
  'Overdue' => 'Te laat',
  'Overview' => 'Overzicht',
  'Parent Task' => 'Bovenliggende taak',
  'Pending' => 'In afwachting',
  'Pending Review' => 'In afwachting van een beoordeling',
  'Process unassigned tasks' => 'Verwerk niet-toegewezen taken',
  'Ready For Review' => 'Klaar voor beoordeling',
  'Receive Notifications for Task Reminder.' => 'Ontvang meldingen voor taakherinnering.',
  'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Meldingen ontvangen voor taken (uiterste datum wijzigingen, statuswijzigingen ...).',
  'Reject Task' => 'Taak weigeren',
  'Remind Mode' => 'Herinneringsmodus',
  'Reminder' => 'Herinnering',
  'Reminder sent' => 'Herinnering verstuurd',
  'Reminders' => 'Herinneringen',
  'Request Review' => 'Beoordeling aanvragen',
  'Request extension' => 'Verzoek om verlenging',
  'Request sent' => 'Verzoek verzonden',
  'Reset Task' => 'Taak opnieuw instellen',
  'Responsible' => 'Verantwoordelijk',
  'Responsible users' => 'Verantwoordelijke gebruikers',
  'Review by responsible user required' => 'Beoordeling door verantwoordelijke gebruiker vereist',
  'Scheduling' => 'Planning',
  'Show widget in Spaces' => 'Widget weergeven in Ruimtes',
  'Show widget on Dashboard' => 'Widget weergeven op dashboard',
  'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Toon {count} voltooide {countTasks,plural,=1{taak} other{taken}} meer.',
  'Sort Order' => 'Sorteervolgorde',
  'Sort order' => 'Sorteervolgorde',
  'Spaces' => 'Ruimten',
  'Start' => 'Start',
  'Start Date' => 'Startdatum',
  'Start Time' => 'Starttijd',
  'Start date' => 'Begindatum',
  'Starting at' => 'Beginnend bij',
  'Status' => 'Status',
  'Task' => 'Taak',
  'Task List' => 'Takenlijst',
  'Task Users have been notified' => 'De betrokken gebruikers zijn op de hoogte gebracht.',
  'Task content ID' => 'Taakinhoud-ID',
  'Task {task} in space {spaceName} ends at {dateTime}.' => 'Taak {task} in ruimte {spaceName} eindigt om {dateTime}.',
  'Task {task} in space {spaceName} starts at {dateTime}.' => 'Taak {task} in ruimte {spaceName} begint om {dateTime}.',
  'Tasks' => 'Taken',
  'Tasks: Reminder' => 'Taken: herinnering',
  'This task requires to be reviewed by a responsible' => 'Een verantwoordelijk moet deze taak beoordelen.',
  'Time Zone' => 'Tijdzone',
  'Title' => 'Samenvatting',
  'Title and Color' => 'Samenvatting en kleur',
  'Title of your task list' => 'Naam van uw takenlijst',
  'Today' => 'Vandaag',
  'Unsorted' => 'Niet toevoegen aan lijst',
  'View Online' => 'Bekijk online',
  'You have insufficient permissions to perform that operation!' => 'U hebt onvoldoende bevoegdheid om deze bewerking uit te voeren!',
  'Your Reminder for task {task}' => 'Uw herinnering voor taak {task}',
  'view all' => 'Bekijk alles',
  '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{# dag} other{# dagen}} resterend',
  '{displayName} is assigned to this task' => '{displayName} is toegewezen aan deze taak',
  '{displayName} is responsible for this task' => '{displayName} is verantwoordelijk voor deze taak',
  '{displayName} is task creator' => '{displayName} is de maker van de taak',
  '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} heeft u verantwoordelijk gemaakt voor taak {task} vanuit de ruimte {spaceName}.',
  '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} wees taak {task} aan u toe in ruimte {spaceName}.',
  '{userName} completed Task {task} in space {spaceName}.' => '{userName} voltooide taak {task} in ruimte {spaceName}.',
  '{userName} completed task {task}.' => '{userName} voltooide taak {task}.',
  '{userName} finished task {task}.' => '{userName} heeft de taak {task} voltooid.',
  '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} wijzigde de uiterste datum voor taak {task} in ruimte {spaceName}.',
  '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} opende taak {task} opnieuw in ruimte {spaceName}.',
  '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} keurde taak {task} in ruimte {spaceName} af als onvolledig.',
  '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName} markeerde taak {taak} in ruimte {spaceName} als voltooid.',
  '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} vraagt om het verschuiven van de uiterste datum voor taak {task} in ruimte {spaceName}.',
  '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} vraagt u om taak {task} in ruimte {spaceName} te bekijken.',
  '{userName} reset task {task}.' => '{userName} stelde taak {task} opnieuw in..',
  '{userName} reviewed task {task}.' => '{userName} beoordeelde taak {task}.',
  '{userName} started working on Task {task} in space {spaceName}.' => '{userName} begon te werken aan Task {task} in ruimte {spaceName}.',
  '{userName} works on task {task}.' => '{userName} werkt aan taak {task}.',
];
